Example
=======================

An example application of this library can be found at the following GitHub
repository. It showcases multithreaded communication and real-time plotting of
live Arduino data with a responsive GUI.

https://github.com/Dennis-van-Gils/DvG_Arduino_PyQt_multithread_demo
